Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Default ¶
func Default() gin.HandlerFunc
Default returns the location middleware with default configuration.
func New ¶
func New(config Config) gin.HandlerFunc
New returns the location middleware with user-defined custom configuration.
Types ¶
type Config ¶
type Config struct {
AllowAllOrigins bool
// AllowedOrigins is a list of origins a cross-domain request can be executed from.
// If the special "*" value is present in the list, all origins will be allowed.
// Default value is []
AllowOrigins []string
// AllowOriginFunc is a custom function to validate the origin. It take the origin
// as argument and returns true if allowed or false otherwise. If this option is
// set, the content of AllowedOrigins is ignored.
AllowOriginFunc func(origin string) bool
// AllowedMethods is a list of methods the client is allowed to use with
// cross-domain requests. Default value is simple methods (GET and POST)
AllowMethods []string
// AllowedHeaders is list of non simple headers the client is allowed to use with
// cross-domain requests.
AllowHeaders []string
// AllowCredentials indicates whether the request can include user credentials like
// cookies, HTTP authentication or client side SSL certificates.
AllowCredentials bool
// ExposedHeaders indicates which headers are safe to expose to the API of a CORS
// API specification
ExposeHeaders []string
// MaxAge indicates how long (in seconds) the results of a preflight request
// can be cached
MaxAge time.Duration
}
Config represents all available options for the middleware.
func DefaultConfig ¶
func DefaultConfig() Config
DefaultConfig returns a generic default configuration mapped to localhost.
func (*Config) AddAllowHeaders ¶
AddAllowHeaders is allowed to add custom headers
func (*Config) AddAllowMethods ¶
AddAllowMethods is allowed to add custom methods
func (*Config) AddExposeHeaders ¶
AddExposeHeaders is allowed to add custom expose headers
Click to show internal directories.
Click to hide internal directories.